# Welcome to pycolorbar

|                      |                                                |
| -------------------- | ---------------------------------------------- |
| Deployment           | [![PyPI](https://badge.fury.io/py/pycolorbar.svg?style=flat)](https://pypi.org/project/pycolorbar/) [![Conda](https://img.shields.io/conda/vn/conda-forge/pycolorbar.svg?logo=conda-forge&logoColor=white&style=flat)](https://anaconda.org/conda-forge/pycolorbar) |
| Activity             | [![PyPI Downloads](https://img.shields.io/pypi/dm/pycolorbar.svg?label=PyPI%20downloads&style=flat)](https://pypi.org/project/pycolorbar/) [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/pycolorbar.svg?label=Conda%20downloads&style=flat)](https://anaconda.org/conda-forge/pycolorbar) |
| Python Versions      | [![Python Versions](https://img.shields.io/badge/Python-3.8%20%203.9%20%203.10%20%203.11%20%203.12-blue?style=flat)](https://www.python.org/downloads/) |
| Supported Systems    | [![Linux](https://img.shields.io/github/actions/workflow/status/ghiggi/pycolorbar/.github/workflows/tests.yml?label=Linux&style=flat)](https://github.com/ghiggi/pycolorbar/actions/workflows/tests.yml) [![macOS](https://img.shields.io/github/actions/workflow/status/ghiggi/pycolorbar/.github/workflows/tests.yml?label=macOS&style=flat)](https://github.com/ghiggi/pycolorbar/actions/workflows/tests.yml) [![Windows](https://img.shields.io/github/actions/workflow/status/ghiggi/pycolorbar/.github/workflows/tests_windows.yml?label=Windows&style=flat)](https://github.com/ghiggi/pycolorbar/actions/workflows/tests_windows.yml) |
| Project Status       | [![Project Status](https://www.repostatus.org/badges/latest/active.svg?style=flat)](https://www.repostatus.org/#active) |
| Build Status         | [![Tests](https://github.com/ghiggi/pycolorbar/actions/workflows/tests.yml/badge.svg?style=flat)](https://github.com/ghiggi/pycolorbar/actions/workflows/tests.yml) [![Lint](https://github.com/ghiggi/pycolorbar/actions/workflows/lint.yml/badge.svg?style=flat)](https://github.com/ghiggi/pycolorbar/actions/workflows/lint.yml) [![Docs](https://readthedocs.org/projects/pycolorbar/badge/?version=latest&style=flat)](https://pycolorbar.readthedocs.io/en/latest/) |
| Linting              | [![Black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat)](https://github.com/psf/black) [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat)](https://github.com/astral-sh/ruff) [![Codespell](https://img.shields.io/badge/Codespell-enabled-brightgreen?style=flat)](https://github.com/codespell-project/codespell) |
| Code Coverage        | [![Coveralls](https://coveralls.io/repos/github/ghiggi/pycolorbar/badge.svg?branch=main&style=flat)](https://coveralls.io/github/ghiggi/pycolorbar?branch=main) [![Codecov](https://codecov.io/gh/ghiggi/pycolorbar/branch/main/graph/badge.svg?style=flat)](https://codecov.io/gh/ghiggi/pycolorbar) |
| Code Quality         | [![Codefactor](https://www.codefactor.io/repository/github/ghiggi/pycolorbar/badge?style=flat)](https://www.codefactor.io/repository/github/ghiggi/pycolorbar) [![Codebeat](https://codebeat.co/badges/236abcf2-cbae-4ca9-8a2d-3b70495bb16b?style=flat)](https://codebeat.co/projects/github-com-ghiggi-pycolorbar-main) [![Codacy](https://app.codacy.com/project/badge/Grade/bee842cb10004ad8bb9288256f2fc8af?style=flat)](https://app.codacy.com/gh/ghiggi/pycolorbar/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade) [![Codescene](https://codescene.io/projects/41870/status-badges/code-health?style=flat)](https://codescene.io/projects/41870) |
| License              | [![License](https://img.shields.io/github/license/ghiggi/pycolorbar?style=flat)](https://github.com/ghiggi/pycolorbar/blob/main/LICENSE) |
| Community            | [![Slack](https://img.shields.io/badge/Slack-pycolorbar-green.svg?logo=slack&style=flat)](https://join.slack.com/t/pycolorbar/shared_invite/zt-2bxdsywo3-368GbufPyb8vNJ1GC9aT3g) [![GitHub Discussions](https://img.shields.io/badge/GitHub-Discussions-green?logo=github&style=flat)](https://github.com/ghiggi/pycolorbar/discussions) |
| Citation             | [![DOI](https://zenodo.org/badge/664671614.svg?style=flat)](https://doi.org/10.5281/zenodo.10613635) |

 [**Slack**](https://join.slack.com/t/pycolorbar/shared_invite/zt-2bxdsywo3-368GbufPyb8vNJ1GC9aT3g) | [**Docs**](https://pycolorbar.readthedocs.io/en/latest/)

The pycolorbar is still in development. Feel free to try it out and to report issues or to suggest changes.

## Quick start

pycolorbar provides a way to define colormaps and colorbar settings for later use in matplotlib or xarray.

Look at the [Tutorials][tutorial_link] to have an overview of the software !

## Installation

### pip

pycolorbar can be installed via [pip][pip_link] on Linux, Mac, and Windows.
On Windows you can install [WinPython][winpy_link] to get Python and pip
running.
Then, install the pycolorbar package by typing the following command in the command terminal:

    pip install pycolorbar

To install the latest development version via pip, see the
[documentation][doc_install_link].

### conda [NOT YET AVAILABLE]

pycolorbar can be installed via [conda][conda_link] on Linux, Mac, and Windows.
Install the package by typing the following command in a command terminal:

    conda install pycolorbar

In case conda forge is not set up for your system yet, see the easy to follow
instructions on [conda forge][conda_forge_link].


## Documentation for pycolorbar

You can find the documentation under [pycolorbar.readthedocs.io][doc_link]

### Tutorials and Examples

The documentation also includes some [tutorials][tutorial_link], showing the most important use cases of pycolorbar.
These tutorial are also available as Jupyter Notebooks and in Google Colab:

- 1. Introduction to colormaps definition [[Notebook][tut3_label_link]][[Colab][colab3_label_link]]
- 2. Introduction to colorbars definition [[Notebook][tut3_label_link]][[Colab][colab3_label_link]]
- 3. Introduction to bivariate colorbars  [[Notebook][tut3_label_link]][[Colab][colab3_label_link]]
- 4. Introduction to trivariate colorbars [[Notebook][tut3_label_link]][[Colab][colab3_label_link]]


## Citation

If you are using pycolorbar in your publication please cite our paper:

TODO: GMD

You can cite the  code publication of pycolorbar by:

> Ghiggi Gionata & XXXX . ghiggi/pycolorbar. Zenodo. https://doi.org/10.5281/zenodo.10613635

If you want to cite a specific version, have a look at the [Zenodo site](https://doi.org/10.5281/zenodo.10613635).

## Requirements:

- [numpy](https://numpy.org/)
- [matplotlib](https://matplotlib.org/)

## License

The content of this repository is released under the terms of the [MIT](LICENSE) license.


[pip_link]: https://pypi.org/project/gstools
[conda_link]: https://docs.conda.io/en/latest/miniconda.html
[conda_forge_link]: https://github.com/conda-forge/pycolorbar-feedstock#installing-pycolorbar
[conda_pip]: https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-pkgs.html#installing-non-conda-packages
[pipiflag]: https://pip-python3.readthedocs.io/en/latest/reference/pip_install.html?highlight=i#cmdoption-i
[winpy_link]: https://winpython.github.io/

[tutorial_link]: https://github.com/ghiggi/pycolorbar/tree/master#tutorials-and-examples

[tut3_label_link]: https://github.com/ghiggi/pycolorbar/tree/master/tutorials
[colab3_label_link]: https://github.com/ghiggi/pycolorbar/tree/master/tutorials

[tut3_patch_link]: https://github.com/ghiggi/pycolorbar/tree/master/tutorials
[colab3_patch_link]: https://github.com/ghiggi/pycolorbar/tree/master/tutorials
